<?php
// $Id: inkribbon.drush.inc,v 1.14.2.5 2010/06/11 21:41:47 mverbaar Exp $

/**
 * Implementation of hook_drush_command().
 */
function inkribbon_drush_command() {
  $items = array();

  $items['inkribbon'] = array(
    'description' => "Create a new Ink Ribbon sub theme.",
    'arguments' => array(
      'name' => 'The name for your sub theme.',
      'machine_name' => '[optional] A machine-readable name for your sub theme.',
    ),
    'examples' => array(
      'drush ink "My awesome sub theme"',
    ),
    'aliases' => array('ink'),
  );

  return $items;
}

/**
 * Command: create a new Ink Ribbon sub theme.
 */
function drush_inkribbon($name = 'My theme', $machine_name = '') {
  $machine_name = ($machine_name) ? $machine_name : preg_replace('/[^a-z0-9]+/', '', strtolower($name));
  $inkribbon_path = drush_locate_root() . '/' . drupal_get_path('theme', 'inkribbon');

  $subtheme_path = split('/', $inkribbon_path);
  array_pop($subtheme_path);
  $subtheme_path = join('/', $subtheme_path) . '/' . $machine_name;

  // Make a fresh copy of the starter kit.
  drush_op('inkribbon_copy', $inkribbon_path . '/STARTERKIT', $subtheme_path, '/^(\.(\.)?|CVS|SVN|\.DS_Store|STARTERKIT\.info\.txt)$/');

  // Create the info file.
  $info = <<<EOF
; \$Id\$
name = $name
description = A starting point for your Ink Ribbon sub theme.
core = 6.x
version = VERSION
engine = phptemplate
base theme = inkribbon

stylesheets[all][] = css/reset.css
; stylesheets[all][] = css/system-messages.css
stylesheets[all][] = css/navigation.css
; stylesheets[all][] = css/fields.css
; stylesheets[all][] = css/comments.css
; stylesheets[all][] = css/nodes.css
; stylesheets[all][] = css/views-styles.css
; stylesheets[all][] = css/blocks.css
stylesheets[all][] = css/layout.css

; Disable CSS from modules that conflict with our design.
stylesheets[all][] = system-menus.css
stylesheets[all][] = user.css

regions[highlight] = Highlighted content
regions[content] = Content
regions[left] = Left sidebar
regions[right] = Right sidebar
regions[header] = Header
regions[footer] = Footer

features[] = logo
features[] = name
features[] = slogan
features[] = favicon
features[] = node_user_picture
features[] = comment_user_picture

EOF;
  drush_op('inkribbon_file_create', $subtheme_path . '/' . $machine_name . '.info', $info);

  // Notify user of the newly created theme.
  drush_print(dt('Theme !name created in !path.',
    array(
      '!name' => $name,
      '!path' => $subtheme_path,
    )));
}

/**
 * Copy a directory recursively.
 *
 * @param $source
 *   The path to the source directory.
 * @param $target
 *   The path to the target directory.
 * @param $ignore
 *   A regex pattern for ignored files.
 */
function inkribbon_copy($source, $target, $ignore = '/^\.(\.)?$/') {
  if (!is_dir($source)) {
    drush_die(dt('The directory !directory was not found.', array('!directory' => $source)));
  }
  $dir = opendir($source);
  // Create the target directory if it doesn't exist.
  @mkdir($target);
  // Go through all the files.
  while($file = readdir($dir)) {
    if (!preg_match($ignore, $file)) {
      if (is_dir($source . '/' . $file)) {
        inkribbon_copy($source . '/' . $file, $target . '/' . $file, $ignore);
      }
      else {
        copy($source . '/' . $file, $target . '/' . $file);
      }
    }
  }
  closedir($dir);
}

/**
 * Create a file.
 *
 * @param $target
 *   The path to the target file.
 * @param $contents
 *   The file contents.
 */
function inkribbon_file_create($target, $contents) {
  // Attempt to create the file if it doesn't exist.
  $file = fopen($target, 'w');
  if (!$file) {
    drush_die(dt('Could not create the file !file.', array('!file' => $target)));
  }
  fwrite($file, $contents);
  fclose($file);
}
